==> toolkit-common-bean-1.1.1-sources.jar: com/meidusa/toolkit/common/bean/config/ConfigUtil.java <==
package com.meidusa.toolkit.common.bean.config;

import java.util.Map;
import java.util.Properties;

import org.apache.commons.collections.map.LRUMap;

import ognl.Ognl;
import ognl.OgnlException;

import com.meidusa.toolkit.common.bean.BeanContext;
import com.meidusa.toolkit.common.bean.BeanContextBean;

/**
 * @author <a href=mailto:piratebase@sina.com>Struct chen</a>
 */
public class ConfigUtil {
	private static Properties properties = new Properties();
	static LRUMap lruMap = new LRUMap(10000);
	static {
		properties.putAll(System.getProperties());
	}
	
    public static void addProperties(Properties properties) {
    	ConfigUtil.properties.putAll(properties);
	}

	public static Properties getProperties() {
		return properties;
	}

	public static Object filter(String text) throws ConfigurationException {
    	Object object = null;
    	try{
    		object = filter(text, BeanContextBean.getInstance());
    	}catch(Exception e){
    	}
    	if(object == null){
    		object = filter(text, properties);
    	}
    	return object;
    }
    
    public static Object filter(String text,BeanContext context){
    	 int propStart = -1;
         int propStop = -1;
         String propName = null;
         propStart = text.indexOf("${", 0);
         if (propStart < 0) {
             return null;
         }
         
         propStop = text.indexOf("}", propStart);
         if (propStop < 0) {
        	 throw new ConfigurationException("Unterminated property: " + text.substring(propStart));
         }
         propName = text.substring(propStart + 2, propStop);
         return context.getBean(propName);
    }
    
    public static String filter(String text, Properties properties) throws ConfigurationException {
        // String result = "";
        StringBuilder result = new StringBuilder();
        int cur = 0;
        int textLen = text.length();
        int propStart = -1;
        int propStop = -1;
        String propName = null;
        String propValue = null;
        for (; cur < textLen; cur = propStop + 1) {
            propStart = text.indexOf("${", cur);
            if (propStart < 0) {
                break;
            }
            result.append(text.substring(cur, propStart));
            // result = result + text.substring(cur, propStart);
            propStop = text.indexOf("}", propStart);
            if (propStop < 0) {
                throw new ConfigurationException("Unterminated property: " + text.substring(propStart));
            }
            propName = text.substring(propStart + 2, propStop);
            propValue = properties.getProperty(propName);
            if (propValue == null) {
                throw new ConfigurationException("No such property: " + propName);
            }
            result.append(propValue);
            // result = result + propValue;
        }

        // result = result + text.substring(cur);
        return result.append(text.substring(cur)).toString();
    }
    
    public static String filterWtihOGNL(String text, Map<String,Object> context,Object root) throws ConfigurationException {
    	return filterWtihOGNL(text,context,root,System.getProperties());
    }
    
    public static String filterWtihOGNL(String text, Map<String,Object> context) throws ConfigurationException {
    	return filterWtihOGNL(text,context,new Object(),System.getProperties());
    }
    
    
    public static String filterWtihOGNL(String text, Map<String,Object> context,Object root,Properties properties) throws ConfigurationException {
        // String result = "";
    	if(properties == null){
    		properties = System.getProperties();
    	}
        StringBuilder result = new StringBuilder();
        int cur = 0;
        int textLen = text.length();
        int propStart = -1;
        int propStop = -1;
        String propName = null;
        String propValue = null;
        for (; cur < textLen; cur = propStop + 1) {
            propStart = text.indexOf("${", cur);
            if (propStart < 0) {
                break;
            }
            result.append(text.substring(cur, propStart));
            // result = result + text.substring(cur, propStart);
            propStop = text.indexOf("}", propStart);
            if (propStop < 0) {
                throw new ConfigurationException("Unterminated property: " + text.substring(propStart));
            }
            propName = text.substring(propStart + 2, propStop);
            if(propName.startsWith("#") || propName.startsWith("@")){
				try {
					Object tree = lruMap.get(propName);
					if(tree == null){
						synchronized (lruMap) {
							tree = lruMap.get(propName);
							if(tree == null){
								tree = Ognl.parseExpression(propName);
								lruMap.put(propName,tree);
							}
						}
					}
					propValue = Ognl.getValue(tree, context,root).toString();
				} catch (OgnlException e) {
					throw new ConfigurationException("parseException expression="+propName,e);
				}
			}else{
				propValue = properties.getProperty(propName);
	            if (propValue == null) {
	                throw new ConfigurationException("No such property: " + propName);
	            }
			}
            result.append(propValue);
        }

        return result.append(text.substring(cur)).toString();
    }
}

==> toolkit-common-bean-1.3.1-sources.jar: com/meidusa/toolkit/common/bean/config/ConfigUtil.java <==
package com.meidusa.toolkit.common.bean.config;

import java.util.Map;
import java.util.Properties;

import org.apache.commons.collections.map.LRUMap;

import ognl.Ognl;
import ognl.OgnlException;

import com.meidusa.toolkit.common.bean.BeanContext;
import com.meidusa.toolkit.common.bean.BeanContextBean;

/**
 * @author <a href=mailto:piratebase@sina.com>Struct chen</a>
 */
public class ConfigUtil {
	private static Properties properties = new Properties();
	static LRUMap lruMap = new LRUMap(10000);
	static {
		properties.putAll(System.getProperties());
	}
	
    public static void addProperties(Properties properties) {
    	ConfigUtil.properties.putAll(properties);
	}

	public static Properties getProperties() {
		return properties;
	}

	public static Object filter(String text) throws ConfigurationException {
    	Object object = null;
    	try{
    		object = filter(text, BeanContextBean.getInstance());
    	}catch(Exception e){
    	}
    	if(object == null){
    		object = filter(text, properties);
    	}
    	return object;
    }
    
    public static Object filter(String text,BeanContext context){
    	 int propStart = -1;
         int propStop = -1;
         String propName = null;
         propStart = text.indexOf("${", 0);
         if (propStart < 0) {
             return text;
         }
         
         propStop = text.indexOf("}", propStart);
         if (propStop < 0) {
        	 throw new ConfigurationException("Unterminated property: " + text.substring(propStart));
         }
         
         if(text.endsWith("}")){
        	 propName = text.substring(propStart + 2, propStop);
        	 return context.getBean(propName);
         }else{
        	return filter(text,properties);
         }
    }
    
    public static String filter(String text, Properties properties) throws ConfigurationException {
        // String result = "";
    	if(text == null) return null;
        StringBuilder result = new StringBuilder();
        int cur = 0;
        int textLen = text.length();
        int propStart = -1;
        int propStop = -1;
        String propName = null;
        String propValue = null;
        for (; cur < textLen; cur = propStop + 1) {
            propStart = text.indexOf("${", cur);
            if (propStart < 0) {
                break;
            }
            result.append(text.substring(cur, propStart));
            // result = result + text.substring(cur, propStart);
            propStop = text.indexOf("}", propStart);
            if (propStop < 0) {
                throw new ConfigurationException("Unterminated property: " + text.substring(propStart));
            }
            propName = text.substring(propStart + 2, propStop);
            int  index = propName.indexOf(":");
            String defValue = null;
            if(index >0){
            	propName = propName.substring(0,index);
            	defValue = propName.substring(index+1);
            }
            propValue = properties.getProperty(propName,defValue);
            if (propValue == null) {
                throw new ConfigurationException("No such property: " + propName);
            }
            result.append(propValue);
            // result = result + propValue;
        }

        // result = result + text.substring(cur);
        return result.append(text.substring(cur)).toString();
    }
    
    public static String filterWtihOGNL(String text, Map<String,Object> context,Object root) throws ConfigurationException {
    	return filterWtihOGNL(text,context,root,System.getProperties());
    }
    
    public static String filterWtihOGNL(String text, Map<String,Object> context) throws ConfigurationException {
    	return filterWtihOGNL(text,context,new Object(),System.getProperties());
    }
    
    
    public static String filterWtihOGNL(String text, Map<String,Object> context,Object root,Properties properties) throws ConfigurationException {
        // String result = "";
    	if(properties == null){
    		properties = System.getProperties();
    	}
        StringBuilder result = new StringBuilder();
        int cur = 0;
        int textLen = text.length();
        int propStart = -1;
        int propStop = -1;
        String propName = null;
        String propValue = null;
        for (; cur < textLen; cur = propStop + 1) {
            propStart = text.indexOf("${", cur);
            if (propStart < 0) {
                break;
            }
            result.append(text.substring(cur, propStart));
            // result = result + text.substring(cur, propStart);
            propStop = text.indexOf("}", propStart);
            if (propStop < 0) {
                throw new ConfigurationException("Unterminated property: " + text.substring(propStart));
            }
            propName = text.substring(propStart + 2, propStop);
            if(propName.startsWith("#") || propName.startsWith("@")){
				try {
					Object tree = lruMap.get(propName);
					if(tree == null){
						synchronized (lruMap) {
							tree = lruMap.get(propName);
							if(tree == null){
								tree = Ognl.parseExpression(propName);
								lruMap.put(propName,tree);
							}
						}
					}
					propValue = Ognl.getValue(tree, context,root).toString();
				} catch (OgnlException e) {
					throw new ConfigurationException("parseException expression="+propName,e);
				}
			}else{
				propValue = properties.getProperty(propName);
	            if (propValue == null) {
	                throw new ConfigurationException("No such property: " + propName);
	            }
			}
            result.append(propValue);
        }

        return result.append(text.substring(cur)).toString();
    }
}
